@@ -40,6 +40,18 @@ int main(int argc, char *argv[])
     notify_init(APP_NAME);
 #endif
 
+    // Style sheet
+#ifdef Q_WS_MAEMO_5
+    QString styleName = "maemo5";
+#else
+    QString styleName = "default";
+#endif
+
+    QFile styleFile(":/res/qss/" + styleName + ".qss");
+    styleFile.open(QFile::ReadOnly);
+    a.setStyleSheet(QString::fromLatin1(styleFile.readAll()));
+    styleFile.close();
+
     MainWindow w;
     w.showMaximized();
     return a.exec();
